package de.hftstuttgart.dtabackend.utils;

import java.io.File;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Helper Class for all file-related tasks.
 *
 * Created by Marcel Bochtler on 05.01.17.
 */
public class FileUtil {

    private static final Logger LOG = LoggerFactory.getLogger(FileUtil.class);

    /**
     * Delete the folder and all containing files.
     * @param folder Folder to delete
     */
    public static void deleteFolderRecursively(File folder) {
        File[] files = folder.listFiles();
        if (files != null) {
            for (File f : files) {
                if (f.isDirectory()) {
                    deleteFolderRecursively(f);
                } else {
                    if (f.delete()) {
                        LOG.debug("Deleted file: {}", f.getAbsolutePath());
                    } else {
                        LOG.debug("Failed to delete file: {}", f.getAbsolutePath());
                    }
                }
            }
        }
        if (folder.delete()) {
            LOG.debug("Deleted folder: {}", folder.getAbsolutePath());
        } else {
            LOG.debug("Failed to delete folder: {}", folder.getAbsolutePath());
        }
    }

    /**
     * Copy the folder and its contents.
     * @param src Source folder path
     * @param dst Destination folder path
     * @throws IOException if an I/O error occurs
     */
    public static void copyFolder(Path src, Path dst) throws IOException {
        Files.walk(src)
            .forEach(source -> {
                try {
                    Path destination = dst.resolve(src.relativize(source));
                    Files.copy(source, destination);
                    LOG.debug("Copying file from: {} to {}", source, destination);
                } catch (IOException e) {
                    LOG.debug("Error copying file from: {} to {}", source, dst.resolve(src.relativize(source)), e);
                    throw new RuntimeException(e.getMessage(), e);
                }
            });
    }
}
